<?php
/**
 * Defines customizer options
 *
 * @package Customizer Library Vogue
 */

function customizer_library_vogue_options() {

    $site_boxed_color = '#FFFFFF';
	$primary_color = '#F061A8';
	$secondary_color = '#EA1B82';

    $header_bg_color = '#FFFFFF';
    $header_font_color = '#2D2D2D';

	$body_font_color = '#3C3C3C';
	$heading_font_color = '#000000';

	// Stores all the controls that will be added
	$options = array();

	// Stores all the sections to be added
	$sections = array();

	// Stores all the panels to be added
	$panels = array();

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// Header Image
    $section = 'header_image';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Site Logo', 'vogue' ),
        'priority' => '25'
    );
    $options['vogue-site-title-uc'] = array(
        'id' => 'vogue-site-title-uc',
        'label'   => __( 'Site Title - Uppercase', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-site-tagline-lc'] = array(
        'id' => 'vogue-site-tagline-lc',
        'label'   => __( 'Site Tagline - Lowercase', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-header-image-logo-max-width'] = array(
        'id' => 'vogue-header-image-logo-max-width',
        'label'   => __( 'Set a max-width for the logo', 'vogue' ),
        'section' => $section,
        'type'    => 'number',
        'description' => __( 'This only applies if a logo image is uploaded', 'vogue' )
    );
    $options['vogue-header-image-show-title'] = array(
        'id' => 'vogue-header-image-show-title',
        'label'   => __( 'Show Site Title', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'description' => __( 'Select this box if you\'ve uploaded a header image below and still want to show the site title next to the image', 'vogue' ),
        'default' => 0,
    );
    $options['vogue-header-image-show-tagline'] = array(
        'id' => 'vogue-header-image-show-tagline',
        'label'   => __( 'Show Site Tagline', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'description' => __( 'Select this box if you\'ve uploaded a header image below and still want to show the Tagline<br /><br /><b>These only work when a header image is uploaded</b>', 'vogue' ),
        'default' => 0,
    );


    $panel = 'vogue-panel-layout';

    $panels[] = array(
        'id' => $panel,
        'title' => __( 'Vogue Theme Settings', 'vogue' ),
        'priority' => '30'
    );

    $section = 'vogue-site-layout-section';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Site Layout', 'vogue' ),
        'priority' => '10',
        'description' => 'Change/edit the <a href="#vogue-header-layout-section" rel="tc-section">Header</a> & <a href="#vogue-footer-layout-section" rel="tc-section">Footer</a> Layouts<br />Add a <a href="#vogue-slider-layout-section" rel="tc-section">Home Page Slider</a><br />Change/edit the <a href="#vogue-blog-list-layout-section" rel="tc-section">Blog Layout</a><br />Add/edit <a href="#vogue-page-layout-section" rel="tc-section">Pages Featured Image</a><br />Add/edit <a href="#vogue-blog-single-layout-section" rel="tc-section">Single Posts featured image</a><br />Add <a href="#vogue-social-section" rel="tc-section">Social Links</a> to your site<br />Edit <a href="#vogue-panel-website-txt" rel="tc-panel">Website Text</a>',
        'panel' => $panel
    );

    $choices = array(
        'vogue-site-boxed' => __( 'Boxed Layout', 'vogue' ),
        'vogue-site-full-width' => __( 'Full Width Layout', 'vogue' )
    );
    $options['vogue-site-layout'] = array(
        'id' => 'vogue-site-layout',
        'label'   => __( 'Site Layout', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'vogue-site-full-width'
    );
    $options['vogue-set-container-width'] = array(
        'id' => 'vogue-set-container-width',
        'label'   => __( 'Site Container Width', 'vogue' ),
        'section' => $section,
        'type'    => 'range',
        'input_attrs' => array(
            'min'   => 900,
            'max'   => 1400,
            'step'  => 2,
        ),
        'description' => __( 'Set the width of your site between 900 pixels and 1400 pixels', 'vogue' ),
        'default' => 1240
    );
    $options['vogue-set-sidebar-width'] = array(
        'id' => 'vogue-set-sidebar-width',
        'label'   => __( 'Sidebar Width', 'vogue' ),
        'section' => $section,
        'type'    => 'range',
        'input_attrs' => array(
            'min'   => 20,
            'max'   => 42,
            'step'  => 1,
        ),
        'default' => 25
    );
    $options['vogue-btt-button'] = array(
        'id' => 'vogue-btt-button',
        'label'   => __( 'Enable a Back To Top button', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-site-add-side-social'] = array(
        'id' => 'vogue-site-add-side-social',
        'label'   => __( 'Add Side Aligned Social Icons', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'description' => __( 'Add <a href="#vogue-social-section" rel="tc-section">Social Icons</a> for this to show', 'vogue' ),
        'default' => 0,
    );
    $choices = array(
        'vogue-side-social-square' => __( 'Square', 'vogue' ),
        'vogue-side-social-round' => __( 'Round', 'vogue' )
    );
    $options['vogue-side-social-look'] = array(
        'id' => 'vogue-side-social-look',
        'label'   => __( 'Side Social Links Design', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'vogue-side-social-square'
    );


    $section = 'vogue-header-layout-section';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Header', 'vogue' ),
        'priority' => '20',
        'description' => 'Edit/Change <a href="#vogue-panel-colors" rel="tc-panel">Header Layout Colors</a><br />Edit <a href="#vogue-website-section-header" rel="tc-section">Header Text</a>',
        'panel' => $panel
    );

    $options['vogue-header-remove-topbar'] = array(
        'id' => 'vogue-header-remove-topbar',
        'label'   => __( 'Remove the Top Bar', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-remove-header-lines'] = array(
        'id' => 'vogue-remove-header-lines',
        'label'   => __( 'Remove Header lines', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );

    $choices = array(
        'vogue-header-layout-one' => __( 'Header Centered One', 'vogue' ),
        'vogue-header-layout-two' => __( 'Header Centered Two', 'vogue' ),
        'vogue-header-layout-three' => __( 'Header Standard', 'vogue' ),
        'vogue-header-layout-four' => __( 'Header Standard Two', 'vogue' )
    );
    $options['vogue-header-layout'] = array(
        'id' => 'vogue-header-layout',
        'label'   => __( 'Header Layout', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'vogue-header-layout-one'
    );

    $choices = array(
        'vogue-header-density-comfortable' => __( 'Comfortable', 'vogue' ),
        'vogue-header-density-compact' => __( 'Compact', 'vogue' )
    );
    $options['vogue-header-density'] = array(
        'id' => 'vogue-header-density',
        'label'   => __( 'Header density', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'vogue-header-density-comfortable'
    );
    $options['vogue-set-sticky-header'] = array(
        'id' => 'vogue-set-sticky-header',
        'label'   => __( 'Sticky Navigation', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0
    );
    $options['vogue-nav-change-case'] = array(
        'id' => 'vogue-nav-change-case',
        'label'   => __( 'Navigation Text - Normal Case', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-header-hide-social'] = array(
        'id' => 'vogue-header-hide-social',
        'label'   => __( 'Remove Social Links', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-header-hide-add'] = array(
        'id' => 'vogue-header-hide-add',
        'label'   => __( 'Remove Address', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-header-hide-no'] = array(
        'id' => 'vogue-header-hide-no',
        'label'   => __( 'Remove Phone Number', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-header-remove-adno-icons'] = array(
        'id' => 'vogue-header-remove-adno-icons',
        'label'   => __( 'Remove Phone & Address Icons', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    // WooCommerce Header Cart
    if ( vogue_is_woocommerce_activated() ) :
        $options['vogue-header-add-drop-cart'] = array(
            'id' => 'vogue-header-add-drop-cart',
            'label'   => __( 'Add WooCommerce Drop Down Cart', 'vogue' ),
            'section' => $section,
            'type'    => 'checkbox',
            'default' => 0,
        );
        $options['vogue-header-remove-cart'] = array(
            'id' => 'vogue-header-remove-cart',
            'label'   => __( 'Remove the WooCommerce Cart', 'vogue' ),
            'section' => $section,
            'type'    => 'checkbox',
            'default' => 0,
        );
    endif;
    $options['vogue-header-search'] = array(
        'id' => 'vogue-header-search',
        'label'   => __( 'Remove Search', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-search-shortcode'] = array(
        'id' => 'vogue-search-shortcode',
        'label'   => __( 'Replace Default Search', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
        'description' => __( 'Enter a shortcode to replace the default search', 'vogue' )
    );
    $options['vogue-noteon-header-search'] = array(
        'id' => 'vogue-noteon-header-search',
        'section' => $section,
        'type'    => 'note',
        'description' => __( 'We recommend <a href="https://kairaweb.com/go/woocommerce-product-search/" target="_blank">WooCommerce Product Search</a> for a better product search for your store', 'vogue' )
    );


    $section = 'vogue-slider-layout-section';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Home Page Slider', 'vogue' ),
        'priority' => '30',
        'panel' => $panel
    );

    $choices = array(
        'vogue-slider-default' => __( 'Default Slider', 'vogue' ),
        'vogue-meta-slider' => __( 'Slider Shortcode', 'vogue' ),
        'vogue-no-slider' => __( 'None', 'vogue' )
    );
    $options['vogue-slider-type'] = array(
        'id' => 'vogue-slider-type',
        'label'   => __( 'Choose a Slider', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'vogue-slider-default'
    );
    $options['vogue-slider-cats'] = array(
        'id' => 'vogue-slider-cats',
        'label'   => __( 'Slider Categories', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
        'description' => __( 'Enter the ID\'s of the post categories you want to display in the slider. Eg: "13,17,19" (no spaces and only comma\'s)<br /><br />Get the ID at <b>Posts -> Categories</b>.<br /><br />Or <a href="https://kairaweb.com/documentation/setting-up-the-default-slider/" target="_blank"><b>See more instructions here</b></a>', 'vogue' )
    );
    $options['vogue-meta-slider-shortcode'] = array(
        'id' => 'vogue-meta-slider-shortcode',
        'label'   => __( 'Slider Shortcode', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
        'description' => __( 'Enter the shortcode given by your slider plugin', 'vogue' )
    );
    $options['vogue-slider-note-shortcode'] = array(
        'id' => 'vogue-slider-note-shortcode',
        'section' => $section,
        'type'    => 'note',
        'description' => __( 'Recommended Advanced Slider: <a href="https://kairaweb.com/go/meta-slider/" target="_blank">Meta Slider</a>', 'vogue' ),
    );
    $choices = array(
        'vogue-slider-size-small' => __( 'Small Slider', 'vogue' ),
        'vogue-slider-size-medium' => __( 'Medium Slider', 'vogue' ),
        'vogue-slider-size-large' => __( 'Large Slider', 'vogue' )
    );
    $options['vogue-slider-size'] = array(
        'id' => 'vogue-slider-size',
        'label'   => __( 'Slider Size', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'vogue-slider-size-medium'
    );
    $choices = array(
        'crossfade' => __( 'Cross Fade', 'vogue' ),
        'cover-fade' => __( 'Cover Fade', 'vogue' ),
        'uncover-fade' => __( 'Uncover Fade', 'vogue' ),
        'cover' => __( 'Cover', 'vogue' ),
        'scroll' => __( 'Scroll', 'vogue' )
    );
    $options['vogue-slider-scroll-effect'] = array(
        'id' => 'vogue-slider-scroll-effect',
        'label'   => __( 'Scroll Effect', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'uncover-fade'
    );
    $options['vogue-slider-duration'] = array(
        'id' => 'vogue-slider-duration',
        'label'   => __( 'Scroll Duration', 'vogue' ),
        'section' => $section,
        'type'    => 'number',
        'description' => __( 'The amount of time the slider takes to scroll to the next slide. 1000 = 1 Second', 'vogue' ),
        'default' => 6500,
    );
    $options['vogue-slider-linkto-post'] = array(
        'id' => 'vogue-slider-linkto-post',
        'label'   => __( 'Link Slide to post', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'description' => __( 'Custom links can be specified on each slide post', 'vogue' ),
        'default' => 0,
    );
    $options['vogue-slider-pause-oh'] = array(
        'id' => 'vogue-slider-pause-oh',
        'label'   => __( 'Pause Slider on mouse hover', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-slider-remove-title'] = array(
        'id' => 'vogue-slider-remove-title',
        'label'   => __( 'Remove Slider Text', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-slider-remove-title-sub-txt'] = array(
        'id' => 'vogue-slider-remove-title-sub-txt',
        'label'   => __( 'Remove only the text below title', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-slider-auto-scroll'] = array(
        'id' => 'vogue-slider-auto-scroll',
        'label'   => __( 'Stop Auto Scroll', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-slider-remove-pagination'] = array(
        'id' => 'vogue-slider-remove-pagination',
        'label'   => __( 'Remove Pagination', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-slider-enable-padding'] = array(
        'id' => 'vogue-slider-enable-padding',
        'label'   => __( 'Enable Slider Padding', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-slider-padding'] = array(
        'id' => 'vogue-slider-padding',
        'label'   => __( 'Slider Padding', 'vogue' ),
        'section' => $section,
        'type'    => 'range',
        'input_attrs' => array(
            'min'   => 0,
            'max'   => 100,
            'step'  => 1,
        ),
        'default' => 10
    );


    $section = 'vogue-blog-list-layout-section';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Blog List', 'vogue' ),
        'priority' => '40',
        'panel' => $panel
    );

    $choices = array(
        'blog-left-layout' => __( 'Left Layout', 'vogue' ),
        'blog-right-layout' => __( 'Right Layout', 'vogue' ),
        'blog-top-layout' => __( 'Top Layout', 'vogue' ),
        'blog-alt-layout' => __( 'Alternate Layout', 'vogue' ),
        'blog-grid-layout' => __( 'Masonry Blocks Layout', 'vogue' )
    );
    $options['vogue-blog-layout'] = array(
        'id' => 'vogue-blog-layout',
        'label'   => __( 'Blog Posts Layout', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'description' => __( 'This uses the "Large Size" image cut', 'vogue' ),
        'default' => 'blog-left-layout'
    );
    $choices = array(
        'blog-grid-column-two' => __( '2', 'vogue' ),
        'blog-grid-column-three' => __( '3', 'vogue' ),
        'blog-grid-column-four' => __( '4', 'vogue' ),
        'blog-grid-column-five' => __( '5', 'vogue' )
    );
    $options['vogue-blog-columns'] = array(
        'id' => 'vogue-blog-columns',
        'label'   => __( 'Block Layout Columns', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'blog-grid-column-three'
    );
    $choices = array(
        'blog-style-plain' => __( 'Plain Styling', 'vogue' ),
        'blog-style-block' => __( 'Block Styling', 'vogue' )
    );
    $options['vogue-blog-styling'] = array(
        'id' => 'vogue-blog-styling',
        'label'   => __( 'Blog Styling', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'blog-style-plain'
    );
    $choices = array(
        'blog-img-shape-img' => __( 'Image Shape Blocks', 'vogue' ),
        'blog-img-shape-square' => __( 'Square Images', 'vogue' ),
        'blog-img-shape-round' => __( 'Round Images', 'vogue' )
    );
    $options['vogue-blog-img-shape'] = array(
        'id' => 'vogue-blog-img-shape',
        'label'   => __( 'Blog Image Shape', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'blog-img-shape-img'
    );
    $options['vogue-blog-list-img-cut'] = array(
        'id' => 'vogue-blog-list-img-cut',
        'label'   => __( 'Blog Image Cut', 'vogue' ),
        'section' => $section,
        'type'    => 'imageselect',
        'description' => __( 'Select which cut the Blog list uses<br />Recommended: Optimize images before upload', 'vogue' ),
        'default' => 'large'
    );
    $options['vogue-blog-cats'] = array(
        'id' => 'vogue-blog-cats',
        'label'   => __( 'Exclude Blog Categories', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
        'description' => __( 'Enter the ID\'s of the post categories you\'d like to EXCLUDE from the Blog, enter only the ID\'s with a minus sign (-) before them, separated by a comma (,)<br />Eg: "-13, -17, -19"<br /><br />If you enter the ID\'s without the minus then it\'ll show ONLY posts in those categories.<br /><br />Get the ID at <b>Posts -> Categories</b>.', 'vogue' )
    );
    $choices = array(
        'blog-display-full-text' => __( 'Full Text', 'vogue' ),
        'blog-display-summary' => __( 'Summary', 'vogue' )
    );
    $options['vogue-article-content-display'] = array(
        'id' => 'vogue-article-content-display',
        'label'   => __( 'For each article display:', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'blog-display-full-text'
    );
    $options['vogue-article-content-word-count'] = array(
        'id' => 'vogue-article-content-word-count',
        'label'   => __( 'Amount of words displayed', 'vogue' ),
        'section' => $section,
        'type'    => 'number',
        'default' => 40
    );
    $options['vogue-article-content-readmore'] = array(
        'id' => 'vogue-article-content-readmore',
        'label'   => __( 'Read More Text', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
        'default' => '...Read More'
    );
    $options['vogue-blog-remove-meta'] = array(
        'id' => 'vogue-blog-remove-meta',
        'label'   => __( 'Remove blog meta', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-blog-remove-excerpt'] = array(
        'id' => 'vogue-blog-remove-excerpt',
        'label'   => __( 'Remove Excerpt/Content', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-blog-remove-tags-cats'] = array(
        'id' => 'vogue-blog-remove-tags-cats',
        'label'   => __( 'Remove the tags and categories', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );

    $options['vogue-blog-leftsidebar'] = array(
        'id' => 'vogue-blog-leftsidebar',
        'label'   => __( 'Blog Left Sidebar', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-blog-cat-leftsidebar'] = array(
        'id' => 'vogue-blog-cat-leftsidebar',
        'label'   => __( 'Archives/Categories Left Sidebar', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-blog-single-leftsidebar'] = array(
        'id' => 'vogue-blog-single-leftsidebar',
        'label'   => __( 'Post Single Pages Left Sidebar', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-blog-search-leftsidebar'] = array(
        'id' => 'vogue-blog-search-leftsidebar',
        'label'   => __( 'Search Results Left Sidebar', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-blog-full-width'] = array(
        'id' => 'vogue-blog-full-width',
        'label'   => __( 'Blog Full Width', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-blog-cat-full-width'] = array(
        'id' => 'vogue-blog-cat-full-width',
        'label'   => __( 'Archives/Categories Full Width', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-blog-single-full-width'] = array(
        'id' => 'vogue-blog-single-full-width',
        'label'   => __( 'Post Single Pages Full Width', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-blog-search-full-width'] = array(
        'id' => 'vogue-blog-search-full-width',
        'label'   => __( 'Search Results Full Width', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-remove-cat-pre-title'] = array(
        'id' => 'vogue-remove-cat-pre-title',
        'label'   => __( 'Remove text before Archive Title', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'description' => __( 'This will not update in the Customizer. Exit the Customizer to view the change', 'vogue' ),
        'default' => 0,
    );


    $section = 'vogue-blog-single-layout-section';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Blog Single Posts', 'vogue' ),
        'priority' => '50',
        'panel' => $panel
    );

    $options['vogue-remove-single-pag'] = array(
        'id' => 'vogue-remove-single-pag',
        'label'   => __( 'Remove Next & Premious posts', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $choices = array(
        'vogue-single-page-fimage-layout-none' => __( 'None', 'vogue' ),
        'vogue-single-page-fimage-layout-standard' => __( 'Standard', 'vogue' ),
        'vogue-single-page-fimage-layout-banner' => __( 'Page Banner', 'vogue' )
    );
    $options['vogue-single-page-fimage-layout'] = array(
        'id' => 'vogue-single-page-fimage-layout',
        'label'   => __( 'Featured Image Layout', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'vogue-single-page-fimage-layout-none'
    );
    $choices = array(
        'vogue-single-page-fimage-size-extra-small' => __( 'Extra Small Banner', 'vogue' ),
        'vogue-single-page-fimage-size-small' => __( 'Small Banner', 'vogue' ),
        'vogue-single-page-fimage-size-medium' => __( 'Medium Banner', 'vogue' ),
        'vogue-single-page-fimage-size-large' => __( 'Large Banner', 'vogue' ),
        'vogue-single-page-fimage-size-actual' => __( 'Use Proper Image', 'vogue' )
    );
    $options['vogue-single-page-fimage-size'] = array(
        'id' => 'vogue-single-page-fimage-size',
        'label'   => __( 'Page Banner Size', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'vogue-single-page-fimage-size-medium'
    );
    $options['vogue-single-page-fimage-fullwidth'] = array(
        'id' => 'vogue-single-page-fimage-fullwidth',
        'label'   => __( 'Full Width Banner', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-blog-single-remove-title'] = array(
        'id' => 'vogue-blog-single-remove-title',
        'label'   => __( 'Remove Post Title', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-blog-single-remove-meta'] = array(
        'id' => 'vogue-blog-single-remove-meta',
        'label'   => __( 'Remove Post Meta', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-blog-single-remove-tags-cats'] = array(
        'id' => 'vogue-blog-single-remove-tags-cats',
        'label'   => __( 'Remove the tags and categories', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-single-author-block'] = array(
        'id' => 'vogue-single-author-block',
        'label'   => __( 'Add Post Author Block', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'description' => __( 'This will not update in the Customizer. Exit the Customizer to view the change on the blog post pages', 'vogue' ),
        'default' => 0,
    );


    $section = 'vogue-page-layout-section';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Pages', 'vogue' ),
        'priority' => '60',
        'panel' => $panel
    );
    
    $options['vogue-page-remove-title-line'] = array(
        'id' => 'vogue-page-remove-title-line',
        'label'   => __( 'Remove Page Title Line', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-page-remove-titlebar'] = array(
        'id' => 'vogue-page-remove-titlebar',
        'label'   => __( 'Remove Page Titles', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-titlebar-centered'] = array(
        'id' => 'vogue-titlebar-centered',
        'label'   => __( 'Center Align Page Titles', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );

    $choices = array(
        'vogue-page-fimage-layout-none' => __( 'None', 'vogue' ),
        'vogue-page-fimage-layout-standard' => __( 'Standard', 'vogue' ),
        'vogue-page-fimage-layout-banner' => __( 'Page Banner', 'vogue' )
    );
    $options['vogue-page-fimage-layout'] = array(
        'id' => 'vogue-page-fimage-layout',
        'label'   => __( 'Featured Image Layout', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'vogue-page-fimage-layout-none'
    );
    $choices = array(
        'vogue-page-fimage-size-extra-small' => __( 'Extra Small Banner', 'vogue' ),
        'vogue-page-fimage-size-small' => __( 'Small Banner', 'vogue' ),
        'vogue-page-fimage-size-medium' => __( 'Medium Banner', 'vogue' ),
        'vogue-page-fimage-size-large' => __( 'Large Banner', 'vogue' ),
        'vogue-page-fimage-size-actual' => __( 'Use Proper Image', 'vogue' )
    );
    $options['vogue-page-fimage-size'] = array(
        'id' => 'vogue-page-fimage-size',
        'label'   => __( 'Page Banner Size', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'vogue-page-fimage-size-medium'
    );
    $options['vogue-page-fimage-fullwidth'] = array(
        'id' => 'vogue-page-fimage-fullwidth',
        'label'   => __( 'Full Width Banner', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );


    $section = 'vogue-footer-layout-section';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Footer', 'vogue' ),
        'priority' => '70',
        'description' => 'Edit/Change <a href="#vogue-panel-colors" rel="tc-section">Footer Layout Colors</a><br />Edit <a href="#vogue-website-section-footer" rel="tc-section">Site Attribution Text</a>',
        'panel' => $panel
    );

    $choices = array(
        'vogue-footer-layout-standard' => __( 'Standard Layout', 'vogue' ),
        'vogue-footer-layout-centered' => __( 'Centered Layout', 'vogue' ),
        'vogue-footer-layout-social' => __( 'Social Layout', 'vogue' ),
        'vogue-footer-layout-custom' => __( 'Custom Layout', 'vogue' ),
        'vogue-footer-layout-none' => __( 'None', 'vogue' )
    );
    $options['vogue-footer-layout'] = array(
        'id' => 'vogue-footer-layout',
        'label'   => __( 'Footer Layout', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'vogue-footer-layout-social'
    );
    $options['vogue-footer-privacy-link'] = array(
        'id' => 'vogue-footer-privacy-link',
        'label'   => __( 'Add "Privacy Policy" page link', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-footer-bottombar'] = array(
        'id' => 'vogue-footer-bottombar',
        'label'   => __( 'Remove the Bottom Bar', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-footer-hide-social'] = array(
        'id' => 'vogue-footer-hide-social',
        'label'   => __( 'Remove Social Links', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );

    $choices = array(
        'vogue-footer-custom-cols-1' => __( '1 Column', 'vogue' ),
        'vogue-footer-custom-cols-2' => __( '2 Columns', 'vogue' ),
        'vogue-footer-custom-cols-3' => __( '3 Columns', 'vogue' ),
        'vogue-footer-custom-cols-4' => __( '4 Columns', 'vogue' ),
        'vogue-footer-custom-cols-5' => __( '5 Columns', 'vogue' )
    );
    $options['vogue-footer-custom-cols'] = array(
        'id' => 'vogue-footer-custom-cols',
        'label'   => __( 'Columns', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'vogue-footer-custom-cols-3'
    );

    $options['vogue-footer-customize'] = array(
        'id' => 'vogue-footer-customize',
        'label'   => __( 'Custom Widths', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'description' => __( 'Select this box to manually adjust the columns widths by percentage ( % )', 'vogue' ),
        'default' => 0,
    );

    $options['vogue-footer-customize-col-1'] = array(
        'id' => 'vogue-footer-customize-col-1',
        'label'   => __( 'Column 1 %', 'vogue' ),
        'section' => $section,
        'type'    => 'number',
    );
    $options['vogue-footer-customize-col-2'] = array(
        'id' => 'vogue-footer-customize-col-2',
        'label'   => __( 'Column 2 %', 'vogue' ),
        'section' => $section,
        'type'    => 'number',
    );
    $options['vogue-footer-customize-col-3'] = array(
        'id' => 'vogue-footer-customize-col-3',
        'label'   => __( 'Column 3 %', 'vogue' ),
        'section' => $section,
        'type'    => 'number',
    );
    $options['vogue-footer-customize-col-4'] = array(
        'id' => 'vogue-footer-customize-col-4',
        'label'   => __( 'Column 4 %', 'vogue' ),
        'section' => $section,
        'type'    => 'number',
    );
    $options['vogue-footer-customize-col-5'] = array(
        'id' => 'vogue-footer-customize-col-5',
        'label'   => __( 'Column 5 %', 'vogue' ),
        'section' => $section,
        'type'    => 'number',
    );


    // WooCommerce style Layout
    if ( vogue_is_woocommerce_activated() ) :

        $section = 'vogue-woocommerce-layout-section';

        $sections[] = array(
            'id' => $section,
            'title' => __( 'WooCommerce', 'vogue' ),
            'priority' => '80',
            'panel' => $panel
        );

        $choices = array(
            '2' => __( '2', 'vogue' ),
            '3' => __( '3', 'vogue' ),
            '4' => __( '4', 'vogue' ),
            '5' => __( '5', 'vogue' )
        );
        $options['vogue-woocommerce-custom-cols'] = array(
            'id' => 'vogue-woocommerce-custom-cols',
            'label'   => __( 'Product Columns', 'vogue' ),
            'section' => $section,
            'type'    => 'select',
            'choices' => $choices,
            'default' => '4'
        );
        $options['vogue-woocommerce-products-per-page'] = array(
            'id' => 'vogue-woocommerce-products-per-page',
            'label'   => __( 'Products Per Page', 'vogue' ),
            'section' => $section,
            'type'    => 'number',
            'default' => 8
        );
        $options['vogue-shop-remove-border'] = array(
            'id' => 'vogue-shop-remove-border',
            'label'   => __( 'Remove Product list borders', 'vogue' ),
            'section' => $section,
            'type'    => 'checkbox',
            'default' => 0,
        );
        $options['vogue-woocommerce-shop-leftsidebar'] = array(
            'id' => 'vogue-woocommerce-shop-leftsidebar',
            'label'   => __( 'Shop Page Left Sidebar', 'vogue' ),
            'section' => $section,
            'type'    => 'checkbox',
            'default' => 0,
        );
        $options['vogue-woocommerce-shop-archive-leftsidebar'] = array(
            'id' => 'vogue-woocommerce-shop-archive-leftsidebar',
            'label'   => __( 'Shop Archives Left Sidebar', 'vogue' ),
            'section' => $section,
            'type'    => 'checkbox',
            'default' => 0,
        );
        $options['vogue-woocommerce-shop-single-leftsidebar'] = array(
            'id' => 'vogue-woocommerce-shop-single-leftsidebar',
            'label'   => __( 'Shop Product Pages Left Sidebar', 'vogue' ),
            'section' => $section,
            'type'    => 'checkbox',
            'default' => 0,
        );

        $options['vogue-woocommerce-shop-fullwidth'] = array(
			'id' => 'vogue-woocommerce-shop-fullwidth',
			'label'   => __( 'Shop Page Full Width', 'vogue' ),
			'section' => $section,
			'type'    => 'checkbox',
			'default' => 0,
		);
        $options['vogue-woocommerce-shop-archive-fullwidth'] = array(
            'id' => 'vogue-woocommerce-shop-archive-fullwidth',
            'label'   => __( 'Shop Archives Full Width', 'vogue' ),
            'section' => $section,
            'type'    => 'checkbox',
            'default' => 0,
        );
        $options['vogue-woocommerce-shop-single-fullwidth'] = array(
            'id' => 'vogue-woocommerce-shop-single-fullwidth',
            'label'   => __( 'Shop Product Pages Full Width', 'vogue' ),
            'section' => $section,
            'type'    => 'checkbox',
            'default' => 0,
        );
        $options['vogue-wc-mobile-prod-full-width'] = array(
            'id' => 'vogue-wc-mobile-prod-full-width',
            'label'   => __( 'Products Full Width on Mobile', 'vogue' ),
            'section' => $section,
            'type'    => 'checkbox',
            'default' => 0,
        );

    endif;


    $section = 'vogue-site-seo-section';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'SEO (Search Engine Optimization)', 'vogue' ),
        'priority' => '90',
        'panel' => $panel
    );

    $choices = array(
        '1' => __( 'H1', 'vogue' ),
        '2' => __( 'H2', 'vogue' ),
        '3' => __( 'H3', 'vogue' ),
        '4' => __( 'H4', 'vogue' ),
        '5' => __( 'H5', 'vogue' ),
        '6' => __( 'H6', 'vogue' )
    );
    $options['vogue-seo-site-title-tag'] = array(
        'id' => 'vogue-seo-site-title-tag',
        'label'   => __( 'Site Title Element', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => '1'
    );

    $choices = array(
        '1' => __( 'H1', 'vogue' ),
        '2' => __( 'H2', 'vogue' ),
        '3' => __( 'H3', 'vogue' ),
        '4' => __( 'H4', 'vogue' ),
        '5' => __( 'H5', 'vogue' ),
        '6' => __( 'H6', 'vogue' )
    );
    $options['vogue-seo-site-desc-tag'] = array(
        'id' => 'vogue-seo-site-desc-tag',
        'label'   => __( 'Site Description Element', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => '2'
    );

    $choices = array(
        '1' => __( 'H1', 'vogue' ),
        '2' => __( 'H2', 'vogue' ),
        '3' => __( 'H3', 'vogue' ),
        '4' => __( 'H4', 'vogue' ),
        '5' => __( 'H5', 'vogue' ),
        '6' => __( 'H6', 'vogue' )
    );
    $options['vogue-seo-page-title-tag'] = array(
        'id' => 'vogue-seo-page-title-tag',
        'label'   => __( 'Page Titles Element', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => '3'
    );
    $choices = array(
        '1' => __( 'H1', 'vogue' ),
        '2' => __( 'H2', 'vogue' ),
        '3' => __( 'H3', 'vogue' ),
        '4' => __( 'H4', 'vogue' ),
        '5' => __( 'H5', 'vogue' ),
        '6' => __( 'H6', 'vogue' )
    );
    $options['vogue-seo-blog-post-title-tag'] = array(
        'id' => 'vogue-seo-blog-post-title-tag',
        'label'   => __( 'Blog List Titles Element', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => '3'
    );
    $choices = array(
        '1' => __( 'H1', 'vogue' ),
        '2' => __( 'H2', 'vogue' ),
        '3' => __( 'H3', 'vogue' ),
        '4' => __( 'H4', 'vogue' ),
        '5' => __( 'H5', 'vogue' ),
        '6' => __( 'H6', 'vogue' )
    );
    $options['vogue-seo-widget-title-tag'] = array(
        'id' => 'vogue-seo-widget-title-tag',
        'label'   => __( 'Widget Titles Element', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => '4'
    );


    $panel = 'vogue-panel-colors';

    $panels[] = array(
        'id' => $panel,
        'title' => __( 'Vogue Theme Colors', 'vogue' ),
        'priority' => '40'
    );
    
    // Colors
    $section = 'colors';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Default Colors', 'vogue' ),
        'priority' => '10',
        'panel' => $panel
    );

    $options['vogue-boxed-bg-color'] = array(
        'id' => 'vogue-boxed-bg-color',
        'label'   => __( 'Site Boxed Background Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $site_boxed_color,
    );

    $options['vogue-primary-color'] = array(
        'id' => 'vogue-primary-color',
        'label'   => __( 'Primary Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $primary_color,
    );

    $options['vogue-secondary-color'] = array(
        'id' => 'vogue-secondary-color',
        'label'   => __( 'Secondary Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $secondary_color,
    );

    $section = 'vogue-panel-colors-section-header';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Header', 'vogue' ),
        'priority' => '10',
        'panel' => $panel
    );

    $options['vogue-header-bg-color'] = array(
        'id' => 'vogue-header-bg-color',
        'label'   => __( 'Background Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $header_bg_color,
    );
    $options['vogue-header-font-color'] = array(
        'id' => 'vogue-header-font-color',
        'label'   => __( 'Font Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $header_font_color,
    );

    $options['vogue-topbar-bg-color'] = array(
        'id' => 'vogue-topbar-bg-color',
        'label'   => __( 'Top Bar Background Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $header_bg_color,
    );
    $options['vogue-topbar-font-color'] = array(
        'id' => 'vogue-topbar-font-color',
        'label'   => __( 'Top Bar Font Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $header_font_color,
    );
    if ( vogue_is_woocommerce_activated() ) :
        $options['vogue-wc-cart-bg-color'] = array(
            'id' => 'vogue-wc-cart-bg-color',
            'label'   => __( 'WC Cart Background Color', 'vogue' ),
            'section' => $section,
            'type'    => 'color',
            'default' => $header_bg_color,
        );
        $options['vogue-wc-cart-font-color'] = array(
            'id' => 'vogue-wc-cart-font-color',
            'label'   => __( 'WC Cart Font Color', 'vogue' ),
            'section' => $section,
            'type'    => 'color',
            'default' => $header_font_color,
        );
    endif;

    $section = 'vogue-panel-colors-section-slider';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Default Slider', 'vogue' ),
        'priority' => '20',
        'panel' => $panel
    );
    
    $options['vogue-slider-bg-color'] = array(
        'id' => 'vogue-slider-bg-color',
        'label'   => __( 'Background Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => '#f9f9f9',
    );
    $options['vogue-slider-block-bg-color'] = array(
        'id' => 'vogue-slider-block-bg-color',
        'label'   => __( 'Block Background Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => '#000000',
    );
    $options['vogue-slider-block-font-color'] = array(
        'id' => 'vogue-slider-block-font-color',
        'label'   => __( 'Block Font Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => '#FFFFFF',
    );
    $options['vogue-slider-block-opacity'] = array(
        'id' => 'vogue-slider-block-opacity',
        'label'   => __( 'Block Opacity', 'vogue' ),
        'section' => $section,
        'type'    => 'range',
        'input_attrs' => array(
            'min'   => 0,
            'max'   => 99,
            'step'  => 1,
        ),
        'default' => 60
    );

    $section = 'vogue-panel-colors-section-nav';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Navigation', 'vogue' ),
        'priority' => '30',
        'panel' => $panel
    );

    $options['vogue-nav-bg-color'] = array(
        'id' => 'vogue-nav-bg-color',
        'label'   => __( 'Background Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $header_bg_color,
    );
    $options['vogue-nav-font-color'] = array(
        'id' => 'vogue-nav-font-color',
        'label'   => __( 'Font Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $header_font_color,
    );
    $options['vogue-nav-font-hover-color'] = array(
        'id' => 'vogue-nav-font-hover-color',
        'label'   => __( 'Font Hover Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $primary_color,
    );

    $options['vogue-nav-drop-bg-color'] = array(
        'id' => 'vogue-nav-drop-bg-color',
        'label'   => __( 'Drop Down Bg Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $header_bg_color,
    );
    $options['vogue-nav-drop-font-color'] = array(
        'id' => 'vogue-nav-drop-font-color',
        'label'   => __( 'DropDown Font Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $header_font_color,
    );

    $section = 'vogue-panel-colors-section-nav-mobile';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Mobile Navigation', 'vogue' ),
        'priority' => '40',
        'panel' => $panel
    );

    $choices = array(
        'vogue-mobile-nav-skin-dark' => __( 'Dark Skin', 'vogue' ),
        'vogue-mobile-nav-skin-light' => __( 'Light Skin', 'vogue' ),
        'vogue-mobile-nav-skin-custom' => __( 'Custom Colors', 'vogue' )
    );
    $options['vogue-mobile-nav-skin'] = array(
        'id' => 'vogue-mobile-nav-skin',
        'label'   => __( 'Mobile Navigation Colors', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'vogue-mobile-nav-skin-dark'
    );
    $options['vogue-mobile-nav-bg-color'] = array(
        'id' => 'vogue-mobile-nav-bg-color',
        'label'   => __( 'Background Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => '#000000',
    );
    $options['vogue-mobile-nav-font-color'] = array(
        'id' => 'vogue-mobile-nav-font-color',
        'label'   => __( 'Font Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => '#C5C5C5',
    );
    $options['vogue-mobile-nav-cart-font-color'] = array(
        'id' => 'vogue-mobile-nav-cart-font-color',
        'label'   => __( 'Cart Font Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => '#FFFFFF',
    );

    $section = 'vogue-panel-colors-section-footer';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Footer', 'vogue' ),
        'priority' => '50',
        'panel' => $panel
    );

    $options['vogue-footer-bg-color'] = array(
        'id' => 'vogue-footer-bg-color',
        'label'   => __( 'Background Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $header_bg_color,
    );
    $options['vogue-footer-heading-font-color'] = array(
        'id' => 'vogue-footer-heading-font-color',
        'label'   => __( 'Heading Font Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $header_font_color,
    );
    $options['vogue-footer-font-color'] = array(
        'id' => 'vogue-footer-font-color',
        'label'   => __( 'Font Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $header_font_color,
    );
    $options['vogue-footer-font-link-color'] = array(
        'id' => 'vogue-footer-font-link-color',
        'label'   => __( 'Link Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $primary_color,
    );
    $options['vogue-footer-font-link-hover-color'] = array(
        'id' => 'vogue-footer-font-link-hover-color',
        'label'   => __( 'Link Hover Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $secondary_color,
    );

    $options['vogue-footer-bottombar-bg-color'] = array(
        'id' => 'vogue-footer-bottombar-bg-color',
        'label'   => __( 'Bottom Bar Bg Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $header_bg_color,
    );
    $options['vogue-footer-bottombar-font-color'] = array(
        'id' => 'vogue-footer-bottombar-font-color',
        'label'   => __( 'Bottom Bar Font Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $header_font_color,
    );
    $options['vogue-footer-bottombar-font-hover-color'] = array(
        'id' => 'vogue-footer-bottombar-font-hover-color',
        'label'   => __( 'Bottom Bar Link Hover Color', 'vogue' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $secondary_color,
    );


    $panel = 'vogue-panel-typo-layout';

    $panels[] = array(
        'id' => $panel,
        'title' => __( 'Vogue Theme Fonts', 'vogue' ),
        'priority' => '40'
    );

	$section = 'vogue-typography-section-title';
	$font_choices = customizer_library_get_font_choices();

	$sections[] = array(
		'id' => $section,
		'title' => __( 'Site Title/Tagline', 'vogue' ),
		'priority' => '10',
        'panel' => $panel
	);

    $options['vogue-title-font'] = array(
        'id' => 'vogue-title-font',
        'label'   => __( 'Site Title Font', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $font_choices,
        'default' => 'Lato'
    );
    $options['vogue-title-font-size'] = array(
        'id' => 'vogue-title-font-size',
        'label'   => __( 'Site Title Size', 'vogue' ),
        'section' => $section,
        'type'    => 'number',
        'default' => 70,
    );
    $options['vogue-tagline-font'] = array(
        'id' => 'vogue-tagline-font',
        'label'   => __( 'Site Tagline Font', 'vogue' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $font_choices,
        'default' => 'Lato'
    );
    $options['vogue-tagline-font-size'] = array(
        'id' => 'vogue-tagline-font-size',
        'label'   => __( 'Site Tagline Size', 'vogue' ),
        'section' => $section,
        'type'    => 'number',
        'default' => 12,
    );
    $options['vogue-title-bottom-margin'] = array(
        'id' => 'vogue-title-bottom-margin',
        'label'   => __( 'Site Title Bottom Margin', 'vogue' ),
        'section' => $section,
        'type'    => 'number',
        'description' => __( 'This will set the space between the site title and the site tagline', 'vogue' ),
        'default' => 0,
    );

    $section = 'vogue-typography-section-default';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Site Defaults', 'vogue' ),
        'priority' => '20',
        'panel' => $panel
    );

	$options['vogue-body-font'] = array(
		'id' => 'vogue-body-font',
		'label'   => __( 'Body Font', 'vogue' ),
		'section' => $section,
		'type'    => 'select',
		'choices' => $font_choices,
		'default' => 'Open Sans'
	);
	$options['vogue-body-font-color'] = array(
		'id' => 'vogue-body-font-color',
		'label'   => __( 'Body Font Color', 'vogue' ),
		'section' => $section,
		'type'    => 'color',
		'default' => $body_font_color,
	);

	$options['vogue-heading-font'] = array(
		'id' => 'vogue-heading-font',
		'label'   => __( 'Heading Font', 'vogue' ),
		'section' => $section,
		'type'    => 'select',
		'choices' => $font_choices,
		'default' => 'Lato'
	);
	$options['vogue-heading-font-color'] = array(
		'id' => 'vogue-heading-font-color',
		'label'   => __( 'Heading Font Color', 'vogue' ),
		'section' => $section,
		'type'    => 'color',
		'default' => $heading_font_color,
	);
    $options['vogue-note-fonts'] = array(
        'id' => 'vogue-note-fonts',
        'section' => $section,
        'type'    => 'note',
        'description' => __( 'We have documentation on <a href="https://kairaweb.com/documentation/change-font-sizes-custom-css/" target="_blank">changing theme font sizes</a>', 'vogue' ),
    );


	// Site Text Settings
    $panel = 'vogue-panel-website-txt';
    
    $panels[] = array(
        'id' => $panel,
        'title' => __( 'Vogue Theme Text', 'vogue' ),
        'priority' => '50'
    );
    
    $section = 'vogue-website-section-header';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Header', 'vogue' ),
        'priority' => '20',
        'panel' => $panel
    );

    $options['vogue-website-site-add'] = array(
        'id' => 'vogue-website-site-add',
        'label'   => __( 'Address', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
        'default' => __( 'Cape Town, South Africa', 'vogue' ),
        'description' => __( 'The address in the Header and Social Footer', 'vogue' )
    );
    $options['vogue-website-head-no'] = array(
        'id' => 'vogue-website-head-no',
        'label'   => __( 'Phone Number', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
        'default' => __( 'Call Us: +2782 444 YEAH', 'vogue' )
    );
    $options['vogue-website-txt-search-txt'] = array(
        'id' => 'vogue-website-txt-search-txt',
        'label'   => __( 'Search Bar Text', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
        'default' => __( 'Search &amp; hit enter', 'vogue')
    );
    
    $section = 'vogue-website-section-footer';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Footer', 'vogue' ),
        'priority' => '20',
        'panel' => $panel
    );

    $options['vogue-website-txt-copy'] = array(
        'id' => 'vogue-website-txt-copy',
        'label'   => __( 'Attribution Text', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
        'default' => __( 'Theme: <a href="https://demo.kairaweb.com/#vogue">Vogue</a> by Kaira', 'vogue')
    );
    
    $section = 'vogue-website-section-error';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Error 404 & Not Found', 'vogue' ),
        'priority' => '20',
        'panel' => $panel
    );
    
    $options['vogue-website-error-head'] = array(
        'id' => 'vogue-website-error-head',
        'label'   => __( '404 Error Page Heading', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
        'default' => __( 'Oops! <span>404</span>', 'vogue'),
        'description' => __( 'Enter the heading for the 404 Error page', 'vogue' )
    );
    $options['vogue-website-error-msg'] = array(
        'id' => 'vogue-website-error-msg',
        'label'   => __( 'Error 404 Message', 'vogue' ),
        'section' => $section,
        'type'    => 'textarea',
        'default' => __( 'It looks like that page does not exist. <br />Return home or try a search', 'vogue'),
        'description' => __( 'Enter the default text on the 404 error page (Page not found)', 'vogue' )
    );
    $options['vogue-website-nosearch-msg'] = array(
        'id' => 'vogue-website-nosearch-msg',
        'label'   => __( 'No Search Results', 'vogue' ),
        'section' => $section,
        'type'    => 'textarea',
        'default' => __( 'Sorry, but nothing matched your search terms. Please try again with some different keywords.', 'vogue'),
        'description' => __( 'Enter the default text for when no search results are found', 'vogue' )
    );


    // Site Text Settings
    $panel = 'vogue-panel-mobile-set';
    
    $panels[] = array(
        'id' => $panel,
        'title' => __( 'Vogue Mobile Settings', 'vogue' ),
        'priority' => '50'
    );
    
    $section = 'vogue-mobile-section-header';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Header', 'vogue' ),
        'priority' => '20',
        'panel' => $panel
    );
    $options['vogue-header-menu-text'] = array(
        'id' => 'vogue-header-menu-text',
        'label'   => __( 'Menu Button Text', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
        'default' => 'menu',
        'description' => __( 'This is the text for the mobile menu button', 'vogue' )
    );
    $options['vogue-header-sticky-nav-onmobile'] = array(
        'id' => 'vogue-header-sticky-nav-onmobile',
        'label'   => __( 'Remove Sticky Navigation on Mobile', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'description' => __( 'Only if Sticky Navigation is enabled', 'vogue' ),
        'default' => 0,
    );
    
    $section = 'vogue-mobile-panel-section-slider';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Home Page Slider', 'vogue' ),
        'priority' => '20',
        'panel' => $panel
    );
    $options['vogue-slider-mobile-set-height'] = array(
        'id' => 'vogue-slider-mobile-set-height',
        'label'   => __( 'Add set height to Slides', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-slider-mobile-remove-txt'] = array(
        'id' => 'vogue-slider-mobile-remove-txt',
        'label'   => __( 'Remove Slider Text', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );


	// Social Settings
    $section = 'vogue-social-section';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Vogue Social Links', 'vogue' ),
        'priority' => '50'
    );

    $options['vogue-social-email'] = array(
        'id' => 'vogue-social-email',
        'label'   => __( 'Email Address', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-skype'] = array(
        'id' => 'vogue-social-skype',
        'label'   => __( 'Skype Name', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-facebook'] = array(
        'id' => 'vogue-social-facebook',
        'label'   => __( 'Facebook', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-twitter'] = array(
        'id' => 'vogue-social-twitter',
        'label'   => __( 'Twitter', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-google-plus'] = array(
        'id' => 'vogue-social-google-plus',
        'label'   => __( 'Google Plus', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-snapchat'] = array(
        'id' => 'vogue-social-snapchat',
        'label'   => __( 'SnapChat', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-etsy'] = array(
        'id' => 'vogue-social-etsy',
        'label'   => __( 'Etsy', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-yelp'] = array(
        'id' => 'vogue-social-yelp',
        'label'   => __( 'Yelp', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-youtube'] = array(
        'id' => 'vogue-social-youtube',
        'label'   => __( 'YouTube', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-instagram'] = array(
        'id' => 'vogue-social-instagram',
        'label'   => __( 'Instagram', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-pinterest'] = array(
        'id' => 'vogue-social-pinterest',
        'label'   => __( 'Pinterest', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-medium'] = array(
        'id' => 'vogue-social-medium',
        'label'   => __( 'Medium', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-behance'] = array(
        'id' => 'vogue-social-behance',
        'label'   => __( 'Behance', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-product-hunt'] = array(
        'id' => 'vogue-social-product-hunt',
        'label'   => __( 'Product Hunt', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-slack'] = array(
        'id' => 'vogue-social-slack',
        'label'   => __( 'Slack', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-linkedin'] = array(
        'id' => 'vogue-social-linkedin',
        'label'   => __( 'LinkedIn', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-tumblr'] = array(
        'id' => 'vogue-social-tumblr',
        'label'   => __( 'Tumblr', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-flickr'] = array(
        'id' => 'vogue-social-flickr',
        'label'   => __( 'Flickr', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-houzz'] = array(
        'id' => 'vogue-social-houzz',
        'label'   => __( 'Houzz', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-vk'] = array(
        'id' => 'vogue-social-vk',
        'label'   => __( 'VK', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-tripadvisor'] = array(
        'id' => 'vogue-social-tripadvisor',
        'label'   => __( 'TripAdvisor', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-github'] = array(
        'id' => 'vogue-social-github',
        'label'   => __( 'GitHub', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-custom-class'] = array(
        'id' => 'vogue-social-custom-class',
        'label'   => __( 'Add a Custom Social Link', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
        'description' => __( 'Add your own social icon by pasting the correct <a href="https://fontawesome.com/cheatsheet" target="_blank">Font Awesome</a> class here<br />Eg: "fa-facebook"<br />This only accepts Brand Icons', 'vogue' ),
    );
    $options['vogue-social-custom-url'] = array(
        'id' => 'vogue-social-custom-url',
        'label'   => __( 'Add the URL', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['vogue-social-custom-class-two'] = array(
        'id' => 'vogue-social-custom-class-two',
        'label'   => __( 'Add a Custom Social Link', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
        'description' => __( 'Add another custom social icon<br />Eg: "fa-pinterest-p"', 'vogue' ),
    );
    $options['vogue-social-custom-url-two'] = array(
        'id' => 'vogue-social-custom-url-two',
        'label'   => __( 'Add the URL', 'vogue' ),
        'section' => $section,
        'type'    => 'text',
    );


    // Site Plugins Support
    $section = 'vogue-plugin-support-section';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Plugin Support', 'vogue' ),
        'priority' => '120',
        'description' => __( 'Vogue adds/removes custom styling to support external plugins', 'vogue' )
    );
    
    $options['vogue-plugin-elementor'] = array(
        'id' => 'vogue-plugin-elementor',
        'label'   => __( 'Elementor', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-plugin-hfelementor'] = array(
        'id' => 'vogue-plugin-hfelementor',
        'label'   => __( 'Header Footer Elementor', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-plugin-styling-buddypress'] = array(
        'id' => 'vogue-plugin-styling-buddypress',
        'label'   => __( 'BuddyPress', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );
    $options['vogue-plugin-mega-menu'] = array(
        'id' => 'vogue-plugin-mega-menu',
        'label'   => __( 'Mega Menu', 'vogue' ),
        'section' => $section,
        'type'    => 'checkbox',
        'default' => 0,
    );


	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// Adds the panels to the $options array
	$options['panels'] = $panels;

	$customizer_library = Customizer_Library::Instance();
	$customizer_library->add_options( $options );

	// To delete custom mods use: customizer_library_remove_theme_mods();

}
add_action( 'init', 'customizer_library_vogue_options' );
