<?php
/**
 * Vogue functions and definitions
 *
 * @package Vogue
 */
define( 'VOGUE_THEME_VERSION' , '10.5.4' ); // VOGUE PREMIUM -------------------------------- YEAH !!

// Include Vogue Premium page
require get_template_directory() . '/premium/premium.php';
// Theme now uses our own update system
require get_template_directory() . '/update.php';

// Load WP included scripts
require get_template_directory() . '/includes/inc/template-tags.php';
require get_template_directory() . '/includes/inc/extras.php';
require get_template_directory() . '/includes/inc/jetpack.php';
require get_template_directory() . '/includes/inc/customizer.php';

// Load Customizer Library scripts
require get_template_directory() . '/customizer/customizer-options.php';
require get_template_directory() . '/customizer/customizer-library/customizer-library.php';
require get_template_directory() . '/customizer/styles.php';
require get_template_directory() . '/customizer/mods.php';

// Load TGM plugin class
require_once get_template_directory() . '/includes/inc/class-tgm-plugin-activation.php';

/*
 * Add the meta boxes to Slider Posts & Pages.
 */
global $pagenow;

if ( $pagenow == 'post.php' ) {

	$vogue_post_id = isset( $_GET['post'] ) ? $_GET['post'] : $_POST['post_ID'] ;
	$vogue_slider_category = get_theme_mod( 'vogue-slider-cats' );

	if ( $vogue_post_id && in_category( array( $vogue_slider_category ), $vogue_post_id ) ) {
		require get_template_directory() . '/includes/inc/slider-post-meta-box.php';
	}
}

if ( ! function_exists( 'vogue_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function vogue_setup() {

	/**
	 * Set the content width based on the theme's design and stylesheet.
	 */
	global $content_width;
	if ( ! isset( $content_width ) ) {
		$content_width = 900; /* pixels */
	}

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on vogue, use a find and replace
	 * to change 'vogue' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'vogue', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );
	add_image_size( 'vogue_blog_img_side', 500, 380, true );
    add_image_size( 'vogue_blog_img_top', 1200, 440, true );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary Menu', 'vogue' ),
        'top-bar-menu' => __( 'Top Bar Menu', 'vogue' ),
        'footer-bar' => __( 'Footer Bar Menu', 'vogue' )
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
	) );

	// The custom header is used for the logo
	add_theme_support( 'custom-header', array(
		'width'         => 280,
		'height'        => 145,
		'flex-width'    => true,
		'flex-height'   => true,
		'header-text'   => false,
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'vogue_custom_background_args', array(
		'default-color' => 'F9F9F9',
	) ) );

	add_theme_support( 'woocommerce' );
	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );
	
	add_theme_support( 'header-footer-elementor' );
}
endif; // vogue_setup
add_action( 'after_setup_theme', 'vogue_setup' );

/**
 * Register widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function vogue_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'vogue' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

    register_sidebar( array(
		'name' => __( 'Vogue Footer Centered', 'vogue' ),
		'id' => 'vogue-site-footer-centered',
        'description' => __( 'The footer will add widgets centered below each other.', 'vogue' )
	));

	register_sidebar( array(
		'name' => __( 'Vogue Footer Standard', 'vogue' ),
		'id' => 'vogue-site-footer-standard',
        'description' => __( 'The footer will divide into however many widgets are placed here.', 'vogue' )
	));

	register_sidebar( array(
		'name' => __( 'Vogue Footer Custom 1', 'vogue' ),
		'id' => 'vogue-site-footer-custom-1'
	));
	register_sidebar( array(
		'name' => __( 'Vogue Footer Custom 2', 'vogue' ),
		'id' => 'vogue-site-footer-custom-2'
	));
	register_sidebar( array(
		'name' => __( 'Vogue Footer Custom 3', 'vogue' ),
		'id' => 'vogue-site-footer-custom-3'
	));
	register_sidebar( array(
		'name' => __( 'Vogue Footer Custom 4', 'vogue' ),
		'id' => 'vogue-site-footer-custom-4'
	));
	register_sidebar( array(
		'name' => __( 'Vogue Footer Custom 5', 'vogue' ),
		'id' => 'vogue-site-footer-custom-5'
	));

}
add_action( 'widgets_init', 'vogue_widgets_init' );

/*
 * Change Widgets Title Tags for SEO
 */
function kaira_change_widget_titles( array $params ) {
	$widget_title_tag = get_theme_mod( 'vogue-seo-widget-title-tag', customizer_library_get_default( 'vogue-seo-widget-title-tag' ) );
    $widget =& $params[0];
    $widget['before_title'] = '<h'.esc_attr( $widget_title_tag ).' class="widget-title">';
    $widget['after_title'] = '</h'.esc_attr( $widget_title_tag ).'>';
    return $params;
}
add_filter( 'dynamic_sidebar_params', 'kaira_change_widget_titles', 20 );

/**
 * Enqueue scripts and styles.
 */
function vogue_scripts() {
	wp_enqueue_style( 'vogue-body-font-default', '//fonts.googleapis.com/css?family=Open+Sans:400,300,300italic,400italic,600,600italic,700,700italic', array(), VOGUE_THEME_VERSION );
	wp_enqueue_style( 'vogue-heading-font-default', '//fonts.googleapis.com/css?family=Lato:400,300,300italic,400italic,700,700italic', array(), VOGUE_THEME_VERSION );

	wp_enqueue_style( 'vogue-font-awesome', get_template_directory_uri().'/includes/font-awesome/css/fontawesome-all.css', array(), '5.0.13' );
	wp_enqueue_style( 'vogue-style', get_stylesheet_uri(), array(), VOGUE_THEME_VERSION );

	if ( get_theme_mod( 'vogue-header-layout' ) == 'vogue-header-layout-four' ) :
		wp_enqueue_style( 'vogue-header-style', get_template_directory_uri().'/templates/css/header-four.css', array(), VOGUE_THEME_VERSION );
	elseif ( get_theme_mod( 'vogue-header-layout' ) == 'vogue-header-layout-three' ) :
		wp_enqueue_style( 'vogue-header-style', get_template_directory_uri().'/templates/css/header-three.css', array(), VOGUE_THEME_VERSION );
	elseif ( get_theme_mod( 'vogue-header-layout' ) == 'vogue-header-layout-two' ) :
		wp_enqueue_style( 'vogue-header-style', get_template_directory_uri().'/templates/css/header-two.css', array(), VOGUE_THEME_VERSION );
	else :
		wp_enqueue_style( 'vogue-header-style', get_template_directory_uri().'/templates/css/header-one.css', array(), VOGUE_THEME_VERSION );
	endif;

	if ( vogue_is_woocommerce_activated() ) :
		wp_enqueue_style( 'vogue-standard-woocommerce-style', get_template_directory_uri().'/templates/css/woocommerce-standard-style.css', array(), VOGUE_THEME_VERSION );
	endif;

	if ( get_theme_mod( 'vogue-footer-layout' ) == 'vogue-footer-layout-custom' ) :
		wp_enqueue_style( 'vogue-footer-style', get_template_directory_uri().'/templates/css/footer-custom.css', array(), VOGUE_THEME_VERSION );
	elseif ( get_theme_mod( 'vogue-footer-layout' ) == 'vogue-footer-layout-centered' ) :
	    wp_enqueue_style( 'vogue-footer-style', get_template_directory_uri().'/templates/css/footer-centered.css', array(), VOGUE_THEME_VERSION );
	elseif ( get_theme_mod( 'vogue-footer-layout' ) == 'vogue-footer-layout-standard' ) :
	    wp_enqueue_style( 'vogue-footer-style', get_template_directory_uri().'/templates/css/footer-standard.css', array(), VOGUE_THEME_VERSION );
	elseif ( get_theme_mod( 'vogue-footer-layout' ) == 'vogue-footer-layout-none' ) :
	    wp_enqueue_style( 'vogue-footer-style', get_template_directory_uri().'/templates/css/footer-none.css', array(), VOGUE_THEME_VERSION );
	else :
		wp_enqueue_style( 'vogue-footer-style', get_template_directory_uri().'/templates/css/footer-social.css', array(), VOGUE_THEME_VERSION );
	endif;

	if ( get_theme_mod( 'vogue-blog-layout' ) == 'blog-grid-layout' ) :
		wp_enqueue_script( 'jquery-masonry' );
		wp_enqueue_script( 'vogue-masonry-custom', get_template_directory_uri() . '/js/blog-layout.js', array('jquery'), VOGUE_THEME_VERSION, true );
	endif;

	// Selected Plugin Styling
	if ( get_theme_mod( 'vogue-plugin-styling-buddypress' ) ) :
		wp_enqueue_style( 'vogue-plugin-styling-buddypress', get_template_directory_uri().'/templates/css/plugins/vogue-buddypress.css', array(), VOGUE_THEME_VERSION );
	endif;

	wp_enqueue_script( 'caroufredsel', get_template_directory_uri() . '/js/jquery.carouFredSel-6.2.1-packed.js', array('jquery'), VOGUE_THEME_VERSION, true );

	wp_enqueue_script( 'vogue-customjs', get_template_directory_uri() . '/js/custom.js', array('jquery'), VOGUE_THEME_VERSION, true );

	if ( get_theme_mod( 'vogue-set-sticky-header' ) && get_theme_mod( 'vogue-header-layout' ) != 'vogue-header-layout-three' ) {
		if ( get_theme_mod( 'vogue-plugin-elementor' ) ) :
			if ( !wp_script_is( 'elementor-waypoints', 'registered' ) ) :
				wp_enqueue_script( 'jquery-waypoints', get_template_directory_uri() . '/js/waypoints/jquery.waypoints.min.js', array('jquery'), VOGUE_THEME_VERSION, true );
			endif;
			wp_enqueue_script( 'jquery-waypoints-sticky', get_template_directory_uri() . '/js/waypoints/jquery.waypoints-sticky.min.js', array('jquery','elementor-waypoints'), VOGUE_THEME_VERSION, true );
			wp_enqueue_script( 'vogue-sticky-header-waypoints', get_template_directory_uri() . '/js/waypoints/sticky-header.js', array('jquery','elementor-waypoints'), VOGUE_THEME_VERSION, true );
		else :
			wp_enqueue_script( 'jquery-waypoints', get_template_directory_uri() . '/js/waypoints/jquery.waypoints.min.js', array('jquery'), VOGUE_THEME_VERSION, true );
			wp_enqueue_script( 'jquery-waypoints-sticky', get_template_directory_uri() . '/js/waypoints/jquery.waypoints-sticky.min.js', array('jquery'), VOGUE_THEME_VERSION, true );
			wp_enqueue_script( 'vogue-sticky-header-waypoints', get_template_directory_uri() . '/js/waypoints/sticky-header.js', array('jquery'), VOGUE_THEME_VERSION, true );
		endif;
	}

	if ( class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'infinite-scroll' ) ) :
		wp_enqueue_script( 'jquery-masonry' );
		wp_enqueue_script( 'vogue-jetpack-scroll', get_template_directory_uri() . '/js/jetpack-infinite-scroll.js', array('jquery'), VOGUE_THEME_VERSION, true );
	endif;

	wp_enqueue_script( 'vogue-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), VOGUE_THEME_VERSION, true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'vogue_scripts' );

/**
 * Add theme stying to the theme content editor
 */
function vogue_add_editor_styles() {
    add_editor_style( 'style-theme-editor.css' );
}
add_action( 'admin_init', 'vogue_add_editor_styles' );

/**
 * Enqueue admin styling.
 */
function vogue_load_admin_script() {
	global $pagenow;

    wp_enqueue_style( 'vogue-admin-css', get_template_directory_uri() . '/premium/css/admin-css.css' );
    // Only load if on themes.php page
    if ( $pagenow == 'themes.php' ) {
    	wp_enqueue_script( 'vogue-premium-js', get_template_directory_uri() . '/premium/js/upgrade-custom.js', array( 'jquery' ), VOGUE_THEME_VERSION, true );
    }
}
add_action( 'admin_enqueue_scripts', 'vogue_load_admin_script' );

/**
 * Function to create Customizer internal linking.
 */
function vogue_customizer_internal_links() { ?>
   <script type="text/javascript">
    (function($) {
        $(document).ready(function() {
            var api = wp.customize;
            api.bind('ready', function() {
                $(['control', 'section', 'panel']).each(function(i, type) {
                    $('a[rel="tc-'+type+'"]').click(function(e) {
                        e.preventDefault();
                        var id = $(this).attr('href').replace('#', '');
                        if(api[type].has(id)) {
                            api[type].instance(id).focus();
                        }
                    });
                });
            });
        });
    })(jQuery);
   </script><?php
}
add_action( 'customize_controls_print_scripts', 'vogue_customizer_internal_links' );

/**
 * Enqueue vogue custom customizer styling.
 */
function vogue_load_customizer_script() {
    wp_enqueue_script( 'vogue-customizer-js', get_template_directory_uri() . '/customizer/customizer-library/js/customizer-custom.js', array( 'jquery' ), VOGUE_THEME_VERSION, true );
    wp_enqueue_style( 'vogue-customizer-css', get_template_directory_uri() . '/customizer/customizer-library/css/customizer.css' );
}
add_action( 'customize_controls_enqueue_scripts', 'vogue_load_customizer_script' );

/**
 * Check if WooCommerce exists.
 */
if ( ! function_exists( 'vogue_is_woocommerce_activated' ) ) :
	function vogue_is_woocommerce_activated() {
	    if ( class_exists( 'woocommerce' ) ) { return true; } else { return false; }
	}
endif; // vogue_is_woocommerce_activated

// If WooCommerce exists include ajax cart
if ( vogue_is_woocommerce_activated() ) {
	require get_template_directory() . '/includes/inc/woocommerce-header-inc.php';
}

/*
 * Override WooCommerce for product # per row
 */
function vogue_shop_products_per_page( $vogue_wc_ppp ) {
	// $cols contains the current number of products per page based on the value stored on Options -> Reading
	$vogue_wc_ppp = 8;
	if ( get_theme_mod( 'vogue-woocommerce-products-per-page' ) ) :
		$vogue_wc_ppp = esc_attr( get_theme_mod( 'vogue-woocommerce-products-per-page' ) );
	endif;
	return $vogue_wc_ppp;
}
add_filter( 'loop_shop_per_page', 'vogue_shop_products_per_page', 20 );

// Override WooCommerce for product # per row
if ( !function_exists( 'vogue_loop_columns' ) ) :
	function vogue_loop_columns() {
		$vogue_woocommerce_product_cols = 4;
		if ( get_theme_mod( 'vogue-woocommerce-custom-cols' ) ) :
			$vogue_woocommerce_product_cols = esc_attr( get_theme_mod( 'vogue-woocommerce-custom-cols' ) );
		endif;
		return $vogue_woocommerce_product_cols;
	}

	add_filter( 'loop_shop_columns', 'vogue_loop_columns' );
endif;

/**
 * Add classes to the body tag from settings
 */
function vogue_add_body_class( $classes ) {
	if ( get_theme_mod( 'vogue-blog-leftsidebar' ) ) {
		$classes[] = 'vogue-blog-leftsidebar';
	}
	if ( get_theme_mod( 'vogue-blog-cat-leftsidebar' ) ) {
		$classes[] = 'vogue-blog-archives-leftsidebar';
	}
	if ( get_theme_mod( 'vogue-blog-search-leftsidebar' ) ) {
		$classes[] = 'vogue-blog-search-leftsidebar';
	}
	if ( get_theme_mod( 'vogue-blog-single-leftsidebar' ) ) {
		$classes[] = 'vogue-blog-single-leftsidebar';
	}

	if ( get_theme_mod( 'vogue-woocommerce-shop-leftsidebar' ) ) {
		$classes[] = 'vogue-shop-leftsidebar';
	}
	if ( get_theme_mod( 'vogue-woocommerce-shop-archive-leftsidebar' ) ) {
		$classes[] = 'vogue-shop-archives-leftsidebar';
	}
	if ( get_theme_mod( 'vogue-woocommerce-shop-single-leftsidebar' ) ) {
		$classes[] = 'vogue-shop-single-leftsidebar';
	}

	if ( get_theme_mod( 'vogue-woocommerce-shop-fullwidth' ) ) {
		$classes[] = 'vogue-shop-full-width';
	}
	if ( get_theme_mod( 'vogue-woocommerce-shop-archive-fullwidth' ) ) {
		$classes[] = 'vogue-shop-archives-full-width';
	}
	if ( get_theme_mod( 'vogue-woocommerce-shop-single-fullwidth' ) ) {
		$classes[] = 'vogue-shop-single-full-width';
	}

	if ( get_theme_mod( 'vogue-page-remove-titlebar' ) ) {
		$classes[] = 'vogue-shop-remove-titlebar';
	}

	return $classes;
}
add_filter( 'body_class', 'vogue_add_body_class' );

/**
 * Add classes to the admin body class
 */
function vogue_add_admin_body_class() {
	$vogue_admin_class = '';

	if ( get_theme_mod( 'vogue-footer-layout' ) == 'vogue-footer-layout-custom' ) {
		if ( get_theme_mod( 'vogue-footer-custom-cols' ) ) {
			$vogue_admin_class = 'vogue-footer-layout-custom ' . sanitize_html_class( get_theme_mod( 'vogue-footer-custom-cols' ) );
		} else {
			$vogue_admin_class = 'vogue-footer-layout-custom vogue-footer-custom-cols-3';
		}
	} elseif ( get_theme_mod( 'vogue-footer-layout' ) ) {
		$vogue_admin_class = sanitize_html_class( get_theme_mod( 'vogue-footer-layout' ) );
	} else {
		$vogue_admin_class = sanitize_html_class( 'vogue-footer-layout-social' );
	}
	
	return $vogue_admin_class;
}
add_filter( 'admin_body_class', 'vogue_add_admin_body_class' );

/**
 * Add classes to the blog list for styling.
 */
function vogue_add_blog_post_classes ( $classes ) {
	global $current_class;

	if ( is_home() || is_archive() || is_search() ) :
		$vogue_blog_layout = sanitize_html_class( 'blog-left-layout' );
		if ( get_theme_mod( 'vogue-blog-layout' ) ) {
		    $vogue_blog_layout = sanitize_html_class( get_theme_mod( 'vogue-blog-layout' ) );
		}
		$classes[] = $vogue_blog_layout;

		$vogue_blog_style = 'blog-style-plain';
		if ( get_theme_mod( 'vogue-blog-styling' ) ) {
		    $vogue_blog_style = sanitize_html_class( get_theme_mod( 'vogue-blog-styling' ) );
		}
		$classes[] = $vogue_blog_style;

		$classes[] = $current_class;
		$current_class = ( $current_class == 'blog-alt-odd' ) ? sanitize_html_class( 'blog-alt-even' ) : sanitize_html_class( 'blog-alt-odd' );
	endif;

	return $classes;
}
global $current_class;
$current_class = 'blog-alt-odd';
add_filter ( 'post_class' , 'vogue_add_blog_post_classes' );

/**
 * Adjust is_home query if vogue-blog-cats is set
 */
function vogue_set_blog_queries( $query ) {
    $blog_query_set = '';
    if ( get_theme_mod( 'vogue-blog-cats', false ) ) {
        $blog_query_set = get_theme_mod( 'vogue-blog-cats' );
    }

    if ( $blog_query_set ) {
        // do not alter the query on wp-admin pages and only alter it if it's the main query
        if ( !is_admin() && $query->is_main_query() ){
            if ( is_home() ){
                $query->set( 'cat', $blog_query_set );
            }
        }
    }
}
add_action( 'pre_get_posts', 'vogue_set_blog_queries' );

/**
 * Exclude slider category from sidebar widgets
 */
function vogue_exclude_slider_categories_widget( $args ) {
	$exclude = ''; // ID's of the categories to exclude
	if ( get_theme_mod( 'vogue-slider-cats', false ) ) {
        $exclude = esc_attr( get_theme_mod( 'vogue-slider-cats' ) );
    }
	$args['exclude'] = $exclude;
	return $args;
}
add_filter( 'widget_categories_args', 'vogue_exclude_slider_categories_widget' );

/**
 * Display recommended plugins with the TGM class
 */
function vogue_register_required_plugins() {
	$plugins = array(
		// The recommended WordPress.org plugins.
		array(
			'name'      => __( 'Elementor Page Builder', 'vogue' ),
			'slug'      => 'elementor',
			'required'  => false,
		),
		array(
			'name'      => __( 'WooCommerce', 'vogue' ),
			'slug'      => 'woocommerce',
			'required'  => false,
		),
		array(
			'name'      => __( 'Contact Form by WPForms', 'vogue' ),
			'slug'      => 'wpforms-lite',
			'required'  => false,
		),
		array(
			'name'      => __( 'Breadcrumb NavXT', 'vogue' ),
			'slug'      => 'breadcrumb-navxt',
			'required'  => false,
		),
		array(
			'name'      => __( 'Meta Slider', 'vogue' ),
			'slug'      => 'ml-slider',
			'required'  => false,
		)
	);
	$config = array(
		'id'           => 'vogue',
		'menu'         => 'tgmpa-install-plugins'
	);

	tgmpa( $plugins, $config );
}
add_action( 'tgmpa_register', 'vogue_register_required_plugins' );

/**
 * Elementor Check
 */
if ( ! defined( 'ELEMENTOR_PARTNER_ID' ) ) {
	define( 'ELEMENTOR_PARTNER_ID', 2118 );
}
/**
 * WPForms Partner ID
 */
if ( !defined( 'WPFORMS_SHAREASALE_ID' ) ) {
    define( 'WPFORMS_SHAREASALE_ID', 1128843 );
}

/**
 * Register a custom Post Categories ID column
 */
function vogue_edit_cat_columns( $vogue_cat_columns ) {
    $vogue_cat_in = array( 'cat_id' => 'Category ID <span class="cat_id_note">For the Default Slider</span>' );
    $vogue_cat_columns = vogue_cat_columns_array_push_after( $vogue_cat_columns, $vogue_cat_in, 0 );
    return $vogue_cat_columns;
}
add_filter( 'manage_edit-category_columns', 'vogue_edit_cat_columns' );

/**
 * Print the ID column
 */
function vogue_cat_custom_columns( $value, $name, $cat_id ) {
    if( 'cat_id' == $name )
        echo $cat_id;
}
add_filter( 'manage_category_custom_column', 'vogue_cat_custom_columns', 10, 3 );

/**
 * Insert an element at the beggining of the array
 */
function vogue_cat_columns_array_push_after( $src, $vogue_cat_in, $pos ) {
    if ( is_int( $pos ) ) {
        $R = array_merge( array_slice( $src, 0, $pos + 1 ), $vogue_cat_in, array_slice( $src, $pos + 1 ) );
    } else {
        foreach ( $src as $k => $v ) {
            $R[$k] = $v;
            if ( $k == $pos )
                $R = array_merge( $R, $vogue_cat_in );
        }
    }
    return $R;
}

/**
 * Function to remove Category pre-title text
 */
function vogue_cat_title_remove_pretext( $vogue_cat_title ) {
	if ( is_category() ) {
            $vogue_cat_title = single_cat_title( '', false );
        } elseif ( is_tag() ) {
            $vogue_cat_title = single_tag_title( '', false );
        } elseif ( is_author() ) {
            $vogue_cat_title = '<span class="vcard">' . get_the_author() . '</span>' ;
        }
    return $vogue_cat_title;
}
if ( get_theme_mod( 'vogue-remove-cat-pre-title' ) ) :
	add_filter( 'get_the_archive_title', 'vogue_cat_title_remove_pretext' );
endif;

/**
 * Insert an element at the beggining of the array
 */
function vogue_add_author_info_box( $content ) {
	global $post;

	if ( is_singular( 'post' ) && isset( $post->post_author ) ) {
		$display_name = get_the_author_meta( 'display_name', $post->post_author );

		if ( empty( $display_name ) )
			$display_name = get_the_author_meta( 'nickname', $post->post_author );
			$user_description = get_the_author_meta( 'user_description', $post->post_author );
			$user_website = get_the_author_meta( 'url', $post->post_author );
			$user_posts = get_author_posts_url( get_the_author_meta( 'ID' , $post->post_author ) );

		if ( ! empty( $display_name ) )
			$author_details = '<p class="author_name">Author: ' . $display_name . '</p>';

		if ( ! empty( $user_description ) )
			$author_details .= '<p class="author_details">' . get_avatar( get_the_author_meta( 'user_email' ) , 90 ) . nl2br( $user_description ). '</p>';
			$author_details .= '<p class="author_links"><a href="'. $user_posts .'">View all posts by ' . $display_name . '</a>';

		if ( ! empty( $user_website ) ) {
			$author_details .= ' | <a href="' . $user_website .'" target="_blank" rel="nofollow">Website</a></p>';
		} else {
			$author_details .= '</p>';
		}

		// Pass all this info to post content
		$content = $content . '<footer class="author_bio_section" >' . $author_details . '</footer>';
	}

	return $content;
}
if ( get_theme_mod( 'vogue-single-author-block' ) ) :
	add_action( 'the_content', 'vogue_add_author_info_box' );
	remove_filter( 'pre_user_description', 'wp_filter_kses' );
endif;
